/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 03393
 |               DRUG SERVICES RESEARCH SURVEY (DSRS), 1990
 |           (DATASET 0003: PHASE II - CLIENT RECORD ABSTRACTS)
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE clientyp  -9='(-9) UNKNOWN/UNABLE TO DETERMINE' 1='(1) HOSPITAL IN-PATIENT'
                  2='(2) RESIDENTIAL' 3='(3) OUT-PATIENT DETOX/MAINTENANCE'
                  4='(4) OUT-PATIENT DRUG-FREE' 5='(5) ALCOHOL ONLY'
                  7='(7) COMBINATION (SPECIFY)' ;
  VALUE com_time  -9='(-9) NOT RECORDED' ;
  VALUE abs_stat  0='(0) INELIGIBLE' 1='(1) COMPLETE' 2='(2) PARTIAL COMPLETE'
                  3='(3) NO RECORD AVAILABLE' ;
  VALUE trans_no  -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE reabs     0='(0) NO, BOX NOT CHECKED' 1='(1) YES' ;
  VALUE qc_abs    0='(0) NO, BOX NOT CHECKED' 1='(1) YES, BOX CHECKED' ;
  VALUE q2_mo     -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q2_yr     -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q3ffffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO WAITING TIME' ;
  VALUE q4ffffff  -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q5ffffff  -9='(-9) UNKNOWN/NOT MENTIONED' 1='(1) SELF' 2='(2) FAMILY'
                  3='(3) FRIEND/ACQUAINTANCE' 4='(4) CLERGY' 5='(5) SCHOOL'
                  6='(6) SOCIAL SERVICE AGENCY'
                  7='(7) EMPLOYEE ASSISTANCE PROGRAM (EAP)'
                  8='(8) EMPLOYER (OTHER THAN EAP)'
                  9='(9) CRIMINAL JUSTICE/LEGAL SYSTEM-'
                  10='(10) CRIMINAL JUSTICE/LEGAL SYSTEM-'
                  11='(11) CRIMINAL JUSTICE/LEGAL SYSTEM-' 12='(12) PRIVATE PHYSICIAN'
                  13='(13) COMMUNITY MENTAL HEALTH CENTER'
                  14='(14) OTHER HEALTH PROFESSIONAL OR PROVIDER/HOSPITAL'
                  15='(15) ANOTHER ALCOHOL/DRUG ABUSE TREATMENT PROGRAM'
                  88='(88) OTHER(SPECIFY)' ;
  VALUE q6ffffff  -9='(-9) UNKNOWN/NOT MENTIONED' -6='(-6) NOT PERMITTED TO ABSTRACT'
                  1='(1) NO PAYMENT - PUBLIC SUBSIDY'
                  2='(2) NO PAYMENT - PHILANTHROPY'
                  3='(3) NO PAYMENT - NOT OTHERWISE SPECIFIED' 4='(4) SELF-PAY'
                  5='(5) HMO OR OTHER PREPAID PLAN' 6='(6) PRIVATE HEALTH INSURANCE'
                  7='(7) MEDICAID' 8='(8) MEDICARE' 9='(9) DOD' 10='(10) CHAMPUS' 11='(11) VA'
                  12='(12) SOCIAL SERVICES' 13='(13) PUBLIC HOUSING/HOME RELIEF'
                  88='(88) OTHER(SPECIFY)' ;
  VALUE q7ffffff  -9='(-9) UNKNOWN/NOT MENTIONED' -6='(-6) NOT PERMITTED TO ABSTRACT'
                  1='(1) NO PAYMENT - PUBLIC SUBSIDY'
                  2='(2) NO PAYMENT - PHILANTHROPY'
                  3='(3) NO PAYMENT - NOT OTHERWISE SPECIFIED' 4='(4) SELF-PAY'
                  5='(5) HMO OR OTHER PREPAID PLAN' 6='(6) PRIVATE HEALTH INSURANCE'
                  7='(7) MEDICAID' 8='(8) MEDICARE' 9='(9) DOD' 10='(10) CHAMPUS' 11='(11) VA'
                  12='(12) SOCIAL SERVICES' 13='(13) PUBLIC HOUSING/HOME RELIEF'
                  88='(88) OTHER(SPECIFY)' ;
  VALUE q8_mo     -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q8_yr     -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q10fffff  -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q11fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 1='(1) MALE' 2='(2) FEMALE'
                  8='(8) OTHER (SPECIFY)' ;
  VALUE q12fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' 1='(1) WHITE'
                  2='(2) BLACK' 3='(3) AMERICAN INDIAN' 4='(4) ALASKAN NATIVE'
                  5='(5) ASIAN OR PACIFIC ISLANDER' 8='(8) OTHER (SPECIFY)' ;
  VALUE q13fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' 1='(1) HISPANIC'
                  2='(2) NOT OF HISPANIC ORIGIN' 8='(8) OTHER (SPECIFY)' ;
  VALUE q14fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  0='(0) NEVER MARRIED' 1='(1) MARRIED/COMMON LAW' 2='(2) WIDOWED'
                  3='(3) SEPARATED/DIVORCED' 4='(4) SINGLE' 8='(8) OTHER (SPECIFY)' ;
  VALUE q15fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q16fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q17fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  0='(0) NO STABLE ARRANGEMENT(INCLUDE HOMELESS, SHELTERS)'
                  1='(1) WITH PARTNER/SPOUSE' 2='(2) WITH PARENT(S)'
                  3='(3) WITH OTHER FAMILY' 4='(4) WITH UNRELATED OTHER(S)' 5='(5) ALONE'
                  6='(6) WITH NO OTHER ADULT(S)' 7='(7) CONTROLLED ENVIRONMENT'
                  8='(8) OTHER (SPECIFY)' ;
  VALUE q18fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  1='(1) LESS THAN 8 YEARS' 2='(2) 8-11 YEARS'
                  3='(3) < H.S. GRADUATE, NOT OTHERWISE SPECIFIED'
                  4='(4) H.S. GRADUATE/GED' 5='(5) SOME COLLEGE' 6='(6) COLLEGE GRADUATE'
                  7='(7) POSTGRADUATE' 8='(8) OTHER (SPECIFY)' ;
  VALUE q19fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q20fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  1='(1) FULL-TIME (35 HRS/WK OR MORE)'
                  2='(2) PART-TIME (LESS THAN 35 HRS/WK)'
                  3='(3) EMPLOYED, NOT OTHERWISE SPECIFIED'
                  4='(4) KEEPING HOUSE, NOT OTHERWISE EMPLOYED'
                  5='(5) UNEMPLOYED - RETIRED' 6='(6) UNEMPLOYED - DISABLED'
                  7='(7) UNEMPLOYED, NOT OTHERWISE SPECIFIED' 8='(8) OTHER (SPECIFY)' ;
  VALUE q21fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 1='(1) OCCUPATION GIVEN' ;
  VALUE q22fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE q23fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE q24fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE q25fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE q26fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NONE' ;
  VALUE q27fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q28fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q29fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES, SPECIFY BELOW' ;
  VALUE q29a      -9='(-9) UNKNOWN / NOT ASCERTAINED'
                  -5='(-5) INAP - Q29 = NO or MISSING'
                  1='(1) MENTAL ILLNESS SPECIFIED' ;
  VALUE q29a_mcf  -5='(-5) INAP - DUAL DIAGNOSIS NOT INDICATED' 0='(0) NO DIAGNOSIS'
                  1='(1) ALCOHOL-INDUCED DISORDER' 2='(2) SUBSTANCE-INDUCED DISORDER'
                  3='(3) ALCOHOL INTOXICATION' 4='(4) ALCOHOL DEPENDENCE'
                  5='(5) OPIOID DEPENDENCE' 6='(6) COCAINE DEPENDENCE'
                  7='(7) CANNABIS DEPENDENCE' 8='(8) OTHER SUBSTANCE DEPENDENCE'
                  9='(9) ALCOHOL ABUSE' 10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE'
                  12='(12) OPIOID ABUSE' 13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q29a_m0f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) INAP - MULTIPLE DUAL DIAGNOSES NOT INDICATED'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q29a_m1f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) INAP - MULTIPLE DUAL DIAGNOSES NOT INDICATED'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q29a_m2f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) INAP - MULTIPLE DUAL DIAGNOSES NOT INDICATED'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q30fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - MALE CLIENT'
                  0='(0) NOT PREGNANT' 1='(1) PREGNANT' ;
  VALUE q31fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  1='(1) SINGLE DRUG ABUSE ONLY (EXCLUDING ALCOHOL)'
                  2='(2) POLYDRUG ABUSE ONLY (EXCLUDING ALCOHOL)'
                  3='(3) ALCOHOL ABUSE ONLY'
                  4='(4) ALCOHOL ABUSE AND ABUSE OF ONE OTHER DRUG COMBINED'
                  5='(5) ALCOHOL ABUSE AND ABUSE OF TWO OR MORE OTHER DRUGS COMBINED' ;
  VALUE q32fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  1='(1) SINGLE DRUG ABUSE ONLY (EXCLUDING ALCOHOL)'
                  2='(2) POLYDRUG ABUSE ONLY (EXCLUDING ALCOHOL)'
                  3='(3) ALCOHOL ABUSE ONLY'
                  4='(4) ALCOHOL AND OTHER DRUGS ABUSE COMBINED' ;
  VALUE q33fffff  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED' -5='(-5) MISSING'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33a      -9='(-9) UNKNOWN / NOT MENTIONED'
                  1='(1) PRIMARY DIAGNOSIS SPECIFIED' ;
  VALUE q33a_mcf  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED' -5='(-5) INAP'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33b_mcf  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) INAP - MULTIPLE DIAGNOSES NOT AVAILABLE'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33b_m0f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) INAP - MULTIPLE DIAGNOSES NOT AVAILABLE'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33b_m1f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED' -5='(-5) INAP'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33b_m2f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED' -5='(-5) INAP'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33b_m3f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED' -5='(-5) INAP'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33b_m4f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED' -5='(-5) INAP'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33b      -9='(-9) UNKNOWN - NOT MENTIONED'
                  1='(1) PRIMARY DIAGNOSIS SPECIFIED' ;
  VALUE q33b1fff  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED' -5='(-5) MISSING'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q33b2fff  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED' -5='(-5) INAP'
                  0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q35_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q35_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - COCAINE USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q35_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - COCAINE USE NOT INDICATED' ;
  VALUE q36_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q36_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - CRACK USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q36_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - CRACK USE NOT INDICATED' ;
  VALUE q37_ever  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - HERION USE NOT INDICATED' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE q37_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - HERION USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q37_age   -9='(-9) UNKNOWN / NOT MENTIONED'
                  -5='(-5) INAP - HERION USE NOT INDICATED' ;
  VALUE q38_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q38_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NON-TREAT METHADONE NOT INDICATED' 0='(0) NO'
                  1='(1) YES' ;
  VALUE q38_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NON-TREAT METHADONE NOT INDICATED' ;
  VALUE q39_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q39_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER OPIATE USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q39_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER OPIATE USE NOT INDICATED' ;
  VALUE q40_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q40_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - BARBITURATE USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q40_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - BARBITURATE USE NOT INDICATED' ;
  VALUE q41_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q41_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - BENZODIAZEPINE USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q41_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER USE NOT INDICATED' ;
  VALUE q42_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q42_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER SED USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q42_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER SEDATIVE USE NOT INDICATED' ;
  VALUE q43_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q43_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - METHAMPHETAMINE USE NOT INDICATED' 0='(0) NO'
                  1='(1) YES' ;
  VALUE q43_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER METHAMPHETAMINE USE NOT INDICATED' ;
  VALUE q44_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q44_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER AMPHETAMINE USE NOT INDICATED' 0='(0) NO'
                  1='(1) YES' ;
  VALUE q44_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER AMPHETAMINE USE NOT INDICATED' ;
  VALUE q45_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q45_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q45_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER MJ, HASHISH, THC, USE NOT INDICATED' ;
  VALUE q46_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q46_used  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - LOGICAL SKIP' 0='(0) NO'
                  1='(1) YES' ;
  VALUE q46_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - PCP/LSD USE NOT INDICATED' ;
  VALUE q47_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q47_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER HALLUCINOGEN USE NOT INDICATED' 0='(0) NO'
                  1='(1) YES' ;
  VALUE q47_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER HALLUCINOGEN USE NOT INDICATED' ;
  VALUE q48_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q48_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - INHALANT USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q48_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER INHALANT USE NOT INDICATED' ;
  VALUE q49_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q49_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OVER-THE-COUTNER USE NOT INDICATED' 0='(0) NO'
                  1='(1) YES' ;
  VALUE q49_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER OVER-THE-COUNTER USE NOT INDICATED' ;
  VALUE q50_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q50_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - ALCOHOL USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q50_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER ALCOHOL USE NOT INDICATED' ;
  VALUE q51_ever  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE q51_used  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER USE NOT INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q51_age   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - OTHER USE NOT INDICATED' ;
  VALUE q52fffff  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DRUG OF CHOICE NOT SPECIFIED AT ADMISSION'
                  0='(0) NO DRUG OF CHOICE' 35='(35) COCAINE' 36='(36) CRACK' 37='(37) HEROIN'
                  38='(38) NON-TREATMENT METHADONE' 39='(39) OTHER OPIATES/SYNTHETICS'
                  40='(40) BARBITURATES' 41='(41) BENZODIAZEPINES'
                  42='(42) OTHER SEDATIVES/HYPNOTICS' 43='(43) METHAMPHETAMINES'
                  44='(44) OTHER AMPHETAMINES' 45='(45) MARIJUANA/HASHISH/THC'
                  46='(46) PCP/LSD' 47='(47) OTHER HALLUCINOGENS' 48='(48) INHALANTS'
                  49='(49) OVER-THE-COUNTER' 50='(50) ALCOHOL' 51='(51) OTHER' ;
  VALUE q53a      -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q53b      -9='(-9) UNKNOWN / NOT MENTIONED'
                  -5='(-5) INAP - NO LIFE TIME IDU INDICATED' 0='(0) NO' 1='(1) YES' ;
  VALUE q53c      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO IDU INDICATED AT ADMISSION' 1='(1) DAILY'
                  2='(2) REGULARLY BUT NOT DAILY' 3='(3) SPORADICALLY' ;
  VALUE q54fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q54_tstf  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER (SPECIFY)'
                  -5='(-5) INAP - Q54 = 0 OR MISSING' 1='(1) URINE' 2='(2) SERUM/BLOOD'
                  8='(8) OTHER SPECIFY' ;
  VALUE q54_ts0f  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER (SPECIFY)'
                  -5='(-5) INAP - Q54=0 OR MISSING, OR ONLY ONE TEST' 1='(1) URINE'
                  2='(2) SERUM/BLOOD' 8='(8) OTHER SPECIFY' ;
  VALUE q54_mo1f  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - Q54=0 OR MISSING' ;
  VALUE q54_yr1f  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - Q54=0 OR MISSING' ;
  VALUE q54_mo2f  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - Q54=0 OR MISSING' ;
  VALUE q54_yr2f  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - Q54=0 OR MISSING' ;
  VALUE q54a_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54a_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54b_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54b_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54c_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54c_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54d_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54d_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54e_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54e_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54f_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54f_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54g_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54g_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54h_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54h_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54i_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54i_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54j_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54j_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54k_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54k_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54l_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54l_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54m_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54m_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54n_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54n_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54o_1ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q54o_2ff  -5='(-5) BLANK - NOT CHECKED' 1='(1) POSITIVE' ;
  VALUE q55fffff  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP-NO SUBSTANCE ABUSE TESTING INDICATED' ;
  VALUE q56fffff  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP-NO SUBSTANCE ABUSE TESTING INDICATED' 0='(0) NONE' ;
  VALUE q57fffff  -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q57a      -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER (SPECIFY)'
                  -5='(-5) INAP - NO PREVIOUS TX EPISODES' 0='(0) LESS THAN 6 MONTHS'
                  55='(55) LIFETIME' ;
  VALUE q58fffff  -9='(-9) UNKOWN / NOT MENTIONED'
                  -5='(-5) INAP - NO PREVIOUS TX EPISODES' 0='(0) NO' 1='(1) YES'
                  2='(2) YES, DATA OVERFLOW' ;
  VALUE q58_no    -9='(-9) 9 OR MORE TREATMENT EPISODES'
                  -5='(-5) INAP-NO PRIOR TREATMENT EPISODES' 9='(9) 9 OR MORE' ;
  VALUE q58a_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP-NO PRIOR TREATMENT EPISODES' 1='(1) COCAINE' 2='(2) CRACK'
                  3='(3) HEROIN' 4='(4) NON-TREATMENT METHADONE'
                  5='(5) OTHER OPIATES/SYNTHETICS' 6='(6) BARBITUATES'
                  7='(7) BENZODIAZEPINES' 8='(8) OTHER - SPECIFY'
                  9='(9) METHAMPHETAMINES' 10='(10) OTHER AMPHETAMINES'
                  11='(11) MARIJUANA/HASHISH/THC' 12='(12) PCP/LSD'
                  13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS' 15='(15) ALCOHOL'
                  16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER - SPECIFY' ;
  VALUE q58a_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE'
                  -5='(-5) INAP-NO PRIOR TREATMENT EPISODES' 1='(1) COCAINE' 2='(2) CRACK'
                  3='(3) HEROIN' 4='(4) NON-TREATMENT METHADONE'
                  5='(5) OTHER OPIATES/SYNTHETICS' 6='(6) BARBITUATES'
                  7='(7) BENZODIAZEPINES' 8='(8) OTHER - SPECIFY'
                  9='(9) METHAMPHETAMINES' 10='(10) OTHER AMPHETAMINES'
                  11='(11) MARIJUANA/HASHISH/THC' 12='(12) PCP/LSD'
                  13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS' 15='(15) ALCOHOL'
                  16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  77='(77) RECORD STATES NO SECONDARY DRUG USE'
                  88='(88) OTHER - SPECIFY' ;
  VALUE q58a_fac  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO PRIOR TREATMENT EPISODES' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q58a_res  -9='(-9) UNKNOWN/NOT ASCERTAINED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' 8='(8) OTHER - SPECIFY' ;
  VALUE q58b_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER - SPECIFY' ;
  VALUE q58b_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58b_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58b_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' 8='(8) OTHER (SPECIFY)' ;
  VALUE q58c_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58c_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58c_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58c_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' ;
  VALUE q58d_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58d_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58d_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58d_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' ;
  VALUE q58e_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58e_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58e_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58e_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' ;
  VALUE q58f_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58f_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58f_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58f_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' ;
  VALUE q58g_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58g_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58g_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58g_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' ;
  VALUE q58h_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58h_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58h_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58h_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' ;
  VALUE q58i_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58i_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58i_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58i_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' ;
  VALUE q58j_pri  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58j_sec  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -7='(-7) RECORD STATES NO SECONDARY DRUG USE' -5='(-5) INAP'
                  1='(1) COCAINE' 2='(2) CRACK' 3='(3) HEROIN'
                  4='(4) NON-TREATMENT METHADONE' 5='(5) OTHER OPIATES/SYNTHETICS'
                  6='(6) BARBITUATES' 7='(7) BENZODIAZEPINES'
                  8='(8) OTHER SEDATIVES/HYPNOTICS' 9='(9) METHAMPHETAMINES'
                  10='(10) OTHER AMPHETAMINES' 11='(11) MARIJUANA/HASHISH/THC'
                  12='(12) PCP/LSD' 13='(13) OTHER HALLUCINOGENS' 14='(14) INHALANTS'
                  15='(15) ALCOHOL' 16='(16) POLYDRUG (EXCLUDING ALCOHOL)'
                  17='(17) COMBINATION ALCOHOL AND OTHER DRUG'
                  18='(18) SUBSTANCE ABUSE/ MENTAL ILLNESS (DUAL DIAGNOSIS)'
                  88='(88) OTHER (SPECIFY)' ;
  VALUE q58j_fac  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q58j_res  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -5='(-5) INAP - Logical Skip' 1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TREATMENT, REFERRED'
                  3='(3) DID NOT COMPLETE TREATMENT BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TREATMENT BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TREATMENT, NOT MENTIONED BY WHOSE CHOICE'
                  6='(6) INCARCERATED' ;
  VALUE q59_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q59_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO IND COUNSELING INDICATED' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q59_no    -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO IND COUNSELING INDICATED' 0='(0) NONE' ;
  VALUE q60_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q60_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO DRUG EDUCATION INDICATED' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q60_no    -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO GROUP COUNSELING INDICATED' 0='(0) NONE' ;
  VALUE q61_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q61_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - FAMILY COUNSELING NOT GIVEN' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q61_no    -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO FAMILY COUNSELING INDICATED' 0='(0) NONE' ;
  VALUE q62_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q62_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO DRUG EDUCATION INDICATED' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q62_no    -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO DRUG EDUCATION INDICATED' 0='(0) NONE' ;
  VALUE q63_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q63_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO EMPLOYMENT COUNSELING INDICATED' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q64_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q64_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO JOB TRAINING INDICATED' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q65_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q65_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO EDUCATIONAL CLASSES INDICATED' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q66_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q66_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO DETOXIFICATION INDICATED' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q67_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q67_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - ACTIVITY GROUPS INDICATED' 1='(1) HERE'
                  2='(2) ELSEWHERE' ;
  VALUE q68_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q68_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - SELF HELP NOT INDICATED' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q69_ser   -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NOT GIVEN'
                  1='(1) ACTUALLY GIVEN, COMPLETED'
                  2='(2) ACTUALLY GIVEN, NOT COMPLETED'
                  3='(3) ACTUALLY GIVEN, NOT COMPLETED'
                  4='(4) ACTUALLY GIVEN, NOT COMPLETED BUT NOT MENTIONED'
                  5='(5) PLANNED OR RECOMMENDED, CAN''T CONFIRM ACTUALLY GIVEN' ;
  VALUE q69_fac   -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DAY CARE NOT INDICATED' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE q70fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES, SPECIFY BELOW' ;
  VALUE q70a      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP-MEDICATIONS NOT PRESCRIBED'
                  1='(1) MEDICATIONS SPECIFIED' ;
  VALUE q71fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q72fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q73fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q74fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) NO' 1='(1) YES' ;
  VALUE q74a_mo   -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74a_yr   -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74a_tot  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74a_giv  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74a_no   -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74a_pl   -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN'
                  1='(1) HERE' 2='(2) AT HOME' 3='(3) HERE/AT HOME' ;
  VALUE q74b_mo   -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74b_yr   -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74b_tot  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74b_giv  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74b_no   -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN' ;
  VALUE q74b_pl   -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN'
                  1='(1) HERE' 2='(2) AT HOME' 3='(3) HERE/AT HOME' ;
  VALUE q75fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - NO METHADONE GIVEN'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q76fffff  -9='(-9) UNKNOWN/NOT MENTIONED' 0='(0) CLIENT DECEASED'
                  1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DID NOT COMPLETE TX, REFERRED TO ANOTHER PROGRAM'
                  3='(3) DID NOT COMPLETE TX BY ADMINISTRATION CHOICE'
                  4='(4) DID NOT COMPLETE TX BY CLIENT CHOICE'
                  5='(5) DID NOT COMPLETE TX, NOT MENTIONED WHOSE CHOICE'
                  6='(6) INCARCERATED' 8='(8) OTHER (SPECIFY)' ;
  VALUE q76a_mo   -9='(-9) UNKNOWN - NOT MENTIONED' -5='(-5) INAP - NOT DECEASED' ;
  VALUE q76a_yr   -9='(-9) UNKNOWN - NOT MENTIONED' -5='(-5) INAP - NOT DECEASED' ;
  VALUE q76b      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - Q76 CODED 1,2,3,6, OR -9' 1='(1) REASON SPECIFIED' ;
  VALUE q77_mo    -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q77_yr    -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q78_mo    -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q78_yr    -9='(-9) UNKNOWN/NOT MENTIONED' ;
  VALUE q79fffff  -9='(-9) UNKNOWN / NOT MENTIONED' 0='(0) NO' 1='(1) YES, SPECIFY BELOW' ;
  VALUE q79a      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - NO DUAL DIAGNOSIS INDICATED'
                  1='(1) MENTAL ILLNESS SPECIFIED' ;
  VALUE q79a_mcf  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) Inap - Logical Skip' 0='(0) NO DIAGNOSIS'
                  1='(1) ALCOHOL-INDUCED DISORDER' 2='(2) SUBSTANCE-INDUCED DISORDER'
                  3='(3) ALCOHOL INTOXICATION' 4='(4) ALCOHOL DEPENDENCE'
                  5='(5) OPIOID DEPENDENCE' 6='(6) COCAINE DEPENDENCE'
                  7='(7) CANNABIS DEPENDENCE' 8='(8) OTHER SUBSTANCE DEPENDENCE'
                  9='(9) ALCOHOL ABUSE' 10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE'
                  12='(12) OPIOID ABUSE' 13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q79a_m0f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) Inap - Logical Skip' 0='(0) NO DIAGNOSIS'
                  1='(1) ALCOHOL-INDUCED DISORDER' 2='(2) SUBSTANCE-INDUCED DISORDER'
                  3='(3) ALCOHOL INTOXICATION' 4='(4) ALCOHOL DEPENDENCE'
                  5='(5) OPIOID DEPENDENCE' 6='(6) COCAINE DEPENDENCE'
                  7='(7) CANNABIS DEPENDENCE' 8='(8) OTHER SUBSTANCE DEPENDENCE'
                  9='(9) ALCOHOL ABUSE' 10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE'
                  12='(12) OPIOID ABUSE' 13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q79a_m1f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) Inap - Logical Skip' 0='(0) NO DIAGNOSIS'
                  1='(1) ALCOHOL-INDUCED DISORDER' 2='(2) SUBSTANCE-INDUCED DISORDER'
                  3='(3) ALCOHOL INTOXICATION' 4='(4) ALCOHOL DEPENDENCE'
                  5='(5) OPIOID DEPENDENCE' 6='(6) COCAINE DEPENDENCE'
                  7='(7) CANNABIS DEPENDENCE' 8='(8) OTHER SUBSTANCE DEPENDENCE'
                  9='(9) ALCOHOL ABUSE' 10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE'
                  12='(12) OPIOID ABUSE' 13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q79a_m2f  -9='(-9) NOT APPLICABLE' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) Inap - Logical Skip' 0='(0) NO DIAGNOSIS'
                  1='(1) ALCOHOL-INDUCED DISORDER' 2='(2) SUBSTANCE-INDUCED DISORDER'
                  3='(3) ALCOHOL INTOXICATION' 4='(4) ALCOHOL DEPENDENCE'
                  5='(5) OPIOID DEPENDENCE' 6='(6) COCAINE DEPENDENCE'
                  7='(7) CANNABIS DEPENDENCE' 8='(8) OTHER SUBSTANCE DEPENDENCE'
                  9='(9) ALCOHOL ABUSE' 10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE'
                  12='(12) OPIOID ABUSE' 13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORDERS'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE q80fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - DID NOT COMPLETE TX'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81fffff  -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  1='(1) YES, SERVICES SPECIFIED' ;
  VALUE q81a      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81b      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81c      -9='(-9) UNKNOWN/NOT MENTIONED' -7='(-7) NOT ROUTINELY RECORDED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81d      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81e      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81f      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81g      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81h      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81i      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q81j      -9='(-9) UNKNOWN/NOT MENTIONED'
                  -5='(-5) INAP - DID NOT COMPLETE TX OR NO AFTERCARE INDICATED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q82fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  0='(0) NO TREATMENT' 1='(1) HOSPITAL INPATIENT' 2='(2) RESIDENTIAL'
                  3='(3) OUTPATIENT/METHADONE MAINTENANCE' 4='(4) OTHER OUTPATIENT'
                  8='(8) OTHER (SPECIFY)' ;
  VALUE q83fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER (SPECIFY)'
                  -6='(-6) NOT PERMITTED TO ABSTRACT' 0='(0) NO CHARGES' ;
  VALUE q83a      -9='(-9) UNKNOWN/NOT MENTIONED' -5='(-5) INAP - CHARGES WERE BILLED'
                  0='(0) NO' 1='(1) YES' ;
  VALUE q84fffff  -9='(-9) UNKNOWN/NOT MENTIONED' -6='(-6) NOT PERMITTED TO ABSTRACT'
                  0='(0) NO CHARGES' 1='(1) FULL AMOUNT BILLED'
                  2='(2) SLIDING FEE AMOUNT'
                  3='(3) REDUCED AMOUNT (SPECIFY % OF TOTAL IN Q84_PER)'
                  8='(8) OTHER (SPECIFY)' ;
  VALUE q84_per   -9='(-9) UNKNOWN/NOT MENTIONED' -8='(-8) OTHER(SPECIFY)'
                  -6='(-6) NOT PERMITTED TO ABSTRACT'
                  -5='(-5) INAP - NOT REDUCED AMOUNT' ;
  VALUE q85fffff  -5='(-5) NO COMMENTS LISTED' 1='(1) COMMENTS LISTED' ;
  VALUE corrfac   0='(0) NO' 1='(1) YES' ;
  VALUE alchonly  0='(0) NO' 1='(1) YES' ;
  VALUE stratum   1='(1) HOSPITAL IN-PATIENT DRUG TREATMENT'
                  2='(2) RESIDENTIAL DRUG TREATMENT'
                  3='(3) OUT-PATIENT DRUG DETOXIFICATION MAINTENANCE'
                  4='(4) OUT-PATIENT DRUG-FREE TREATMENT'
                  5='(5) ALCOHOL TREATMENT ONLY' 6='(6) UNKNOWN TREATMENT TYPE' ;
  VALUE region    1='(1) NORTHEAST' 2='(2) NORTH CENTRAL' 3='(3) SOUTH' 4='(4) WEST' ;
  VALUE los       -9='(-9) MISSING DATA - NOT ABLE TO BE DERIVED' ;
  VALUE trt_dur   -9='(-9) MISSING DATA - NOT ABLE TO BE DERIVED' ;
  VALUE agea      -9='(-9) MISSING DATA - NOT ABLE TO BE DERIVED' ;
  VALUE aged      -9='(-9) MISSING DATA - NOT ABLE TO BE DERIVED' ;
  VALUE txtype    -9='(-9) UNKNOWN/UNABLE TO DETERMINE' 1='(1) HOSPITAL IN-PATIENT'
                  2='(2) RESIDENTIAL' 3='(3) METHADONE' 4='(4) OUT-PATIENT DRUG FREE'
                  5='(5) ALCOHOL' 7='(7) COMBINATION' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID <= -1) THEN CASEID = .;
   IF (OBS_NUM <= -1) THEN OBS_NUM = .;
   IF (CLIENTYP <= -1) THEN CLIENTYP = .;
   IF (ABSTRACT <= -1) THEN ABSTRACT = .;
   IF (COMP_MO <= -1) THEN COMP_MO = .;
   IF (COMP_YR <= -1) THEN COMP_YR = .;
   IF (COM_TIME <= -1) THEN COM_TIME = .;
   IF (ABS_STAT <= -1) THEN ABS_STAT = .;
   IF (TRANS_NO <= -1) THEN TRANS_NO = .;
   IF (REABS <= -1) THEN REABS = .;
   IF (QC_ABS <= -1) THEN QC_ABS = .;
   IF (Q2_MO <= -1) THEN Q2_MO = .;
   IF (Q2_YR <= -1) THEN Q2_YR = .;
   IF (Q3 <= -1) THEN Q3 = .;
   IF (Q4 <= -1) THEN Q4 = .;
   IF (Q5 <= -1) THEN Q5 = .;
   IF (Q6 <= -1) THEN Q6 = .;
   IF (Q7 <= -1) THEN Q7 = .;
   IF (Q8_MO <= -1) THEN Q8_MO = .;
   IF (Q8_YR <= -1) THEN Q8_YR = .;
   IF (Q10 <= -1) THEN Q10 = .;
   IF (Q11 <= -1) THEN Q11 = .;
   IF (Q12 <= -1) THEN Q12 = .;
   IF (Q13 <= -1) THEN Q13 = .;
   IF (Q14 <= -1) THEN Q14 = .;
   IF (Q15 <= -1) THEN Q15 = .;
   IF (Q16 <= -1) THEN Q16 = .;
   IF (Q17 <= -1) THEN Q17 = .;
   IF (Q18 <= -1) THEN Q18 = .;
   IF (Q19 <= -1) THEN Q19 = .;
   IF (Q20 <= -1) THEN Q20 = .;
   IF (Q21 <= -1) THEN Q21 = .;
   IF (Q21_OCC <= -1) THEN Q21_OCC = .;
   IF (Q22 <= -1) THEN Q22 = .;
   IF (Q23 <= -1) THEN Q23 = .;
   IF (Q24 <= -1) THEN Q24 = .;
   IF (Q25 <= -1) THEN Q25 = .;
   IF (Q26 <= -1) THEN Q26 = .;
   IF (Q27 <= -1) THEN Q27 = .;
   IF (Q28 <= -1) THEN Q28 = .;
   IF (Q29 <= -1) THEN Q29 = .;
   IF (Q29A <= -1) THEN Q29A = .;
   IF (Q29A_MC1 <= -1) THEN Q29A_MC1 = .;
   IF (Q29A_MC2 <= -1) THEN Q29A_MC2 = .;
   IF (Q29A_MC3 <= -1) THEN Q29A_MC3 = .;
   IF (Q29A_MC4 <= -1) THEN Q29A_MC4 = .;
   IF (Q30 <= -1) THEN Q30 = .;
   IF (Q31 <= -1) THEN Q31 = .;
   IF (Q32 <= -1) THEN Q32 = .;
   IF (Q33 <= -1) THEN Q33 = .;
   IF (Q33A <= -1) THEN Q33A = .;
   IF (Q33A_MC1 <= -1) THEN Q33A_MC1 = .;
   IF (Q33B_MC1 <= -1) THEN Q33B_MC1 = .;
   IF (Q33B_MC2 <= -1) THEN Q33B_MC2 = .;
   IF (Q33B_MC3 <= -1) THEN Q33B_MC3 = .;
   IF (Q33B_MC4 <= -1) THEN Q33B_MC4 = .;
   IF (Q33B_MC5 <= -1) THEN Q33B_MC5 = .;
   IF (Q33B_MC6 <= -1) THEN Q33B_MC6 = .;
   IF (Q33B <= -1) THEN Q33B = .;
   IF (Q33B1 <= -1) THEN Q33B1 = .;
   IF (Q33B2 <= -1) THEN Q33B2 = .;
   IF (Q35_EVER <= -1) THEN Q35_EVER = .;
   IF (Q35_USED <= -1) THEN Q35_USED = .;
   IF (Q35_AGE <= -1) THEN Q35_AGE = .;
   IF (Q36_EVER <= -1) THEN Q36_EVER = .;
   IF (Q36_USED <= -1) THEN Q36_USED = .;
   IF (Q36_AGE <= -1) THEN Q36_AGE = .;
   IF (Q37_EVER <= -1) THEN Q37_EVER = .;
   IF (Q37_USED <= -1) THEN Q37_USED = .;
   IF (Q37_AGE <= -1) THEN Q37_AGE = .;
   IF (Q38_EVER <= -1) THEN Q38_EVER = .;
   IF (Q38_USED <= -1) THEN Q38_USED = .;
   IF (Q38_AGE <= -1) THEN Q38_AGE = .;
   IF (Q39_EVER <= -1) THEN Q39_EVER = .;
   IF (Q39_USED <= -1) THEN Q39_USED = .;
   IF (Q39_AGE <= -1) THEN Q39_AGE = .;
   IF (Q40_EVER <= -1) THEN Q40_EVER = .;
   IF (Q40_USED <= -1) THEN Q40_USED = .;
   IF (Q40_AGE <= -1) THEN Q40_AGE = .;
   IF (Q41_EVER <= -1) THEN Q41_EVER = .;
   IF (Q41_USED <= -1) THEN Q41_USED = .;
   IF (Q41_AGE <= -1) THEN Q41_AGE = .;
   IF (Q42_EVER <= -1) THEN Q42_EVER = .;
   IF (Q42_USED <= -1) THEN Q42_USED = .;
   IF (Q42_AGE <= -1) THEN Q42_AGE = .;
   IF (Q43_EVER <= -1) THEN Q43_EVER = .;
   IF (Q43_USED <= -1) THEN Q43_USED = .;
   IF (Q43_AGE <= -1) THEN Q43_AGE = .;
   IF (Q44_EVER <= -1) THEN Q44_EVER = .;
   IF (Q44_USED <= -1) THEN Q44_USED = .;
   IF (Q44_AGE <= -1) THEN Q44_AGE = .;
   IF (Q45_EVER <= -1) THEN Q45_EVER = .;
   IF (Q45_USED <= -1) THEN Q45_USED = .;
   IF (Q45_AGE <= -1) THEN Q45_AGE = .;
   IF (Q46_EVER <= -1) THEN Q46_EVER = .;
   IF (Q46_USED <= -1) THEN Q46_USED = .;
   IF (Q46_AGE <= -1) THEN Q46_AGE = .;
   IF (Q47_EVER <= -1) THEN Q47_EVER = .;
   IF (Q47_USED <= -1) THEN Q47_USED = .;
   IF (Q47_AGE <= -1) THEN Q47_AGE = .;
   IF (Q48_EVER <= -1) THEN Q48_EVER = .;
   IF (Q48_USED <= -1) THEN Q48_USED = .;
   IF (Q48_AGE <= -1) THEN Q48_AGE = .;
   IF (Q49_EVER <= -1) THEN Q49_EVER = .;
   IF (Q49_USED <= -1) THEN Q49_USED = .;
   IF (Q49_AGE <= -1) THEN Q49_AGE = .;
   IF (Q50_EVER <= -1) THEN Q50_EVER = .;
   IF (Q50_USED <= -1) THEN Q50_USED = .;
   IF (Q50_AGE <= -1) THEN Q50_AGE = .;
   IF (Q51_EVER <= -1) THEN Q51_EVER = .;
   IF (Q51_USED <= -1) THEN Q51_USED = .;
   IF (Q51_AGE <= -1) THEN Q51_AGE = .;
   IF (Q52 <= -1) THEN Q52 = .;
   IF (Q53A <= -1) THEN Q53A = .;
   IF (Q53B <= -1) THEN Q53B = .;
   IF (Q53C <= -1) THEN Q53C = .;
   IF (Q54 <= -1) THEN Q54 = .;
   IF (Q54_TST1 <= -1) THEN Q54_TST1 = .;
   IF (Q54_TST2 <= -1) THEN Q54_TST2 = .;
   IF (Q54_MO1 <= -1) THEN Q54_MO1 = .;
   IF (Q54_YR1 <= -1) THEN Q54_YR1 = .;
   IF (Q54_MO2 <= -1) THEN Q54_MO2 = .;
   IF (Q54_YR2 <= -1) THEN Q54_YR2 = .;
   IF (Q54A_1 <= -1) THEN Q54A_1 = .;
   IF (Q54A_2 <= -1) THEN Q54A_2 = .;
   IF (Q54B_1 <= -1) THEN Q54B_1 = .;
   IF (Q54B_2 <= -1) THEN Q54B_2 = .;
   IF (Q54C_1 <= -1) THEN Q54C_1 = .;
   IF (Q54C_2 <= -1) THEN Q54C_2 = .;
   IF (Q54D_1 <= -1) THEN Q54D_1 = .;
   IF (Q54D_2 <= -1) THEN Q54D_2 = .;
   IF (Q54E_1 <= -1) THEN Q54E_1 = .;
   IF (Q54E_2 <= -1) THEN Q54E_2 = .;
   IF (Q54F_1 <= -1) THEN Q54F_1 = .;
   IF (Q54F_2 <= -1) THEN Q54F_2 = .;
   IF (Q54G_1 <= -1) THEN Q54G_1 = .;
   IF (Q54G_2 <= -1) THEN Q54G_2 = .;
   IF (Q54H_1 <= -1) THEN Q54H_1 = .;
   IF (Q54H_2 <= -1) THEN Q54H_2 = .;
   IF (Q54I_1 <= -1) THEN Q54I_1 = .;
   IF (Q54I_2 <= -1) THEN Q54I_2 = .;
   IF (Q54J_1 <= -1) THEN Q54J_1 = .;
   IF (Q54J_2 <= -1) THEN Q54J_2 = .;
   IF (Q54K_1 <= -1) THEN Q54K_1 = .;
   IF (Q54K_2 <= -1) THEN Q54K_2 = .;
   IF (Q54L_1 <= -1) THEN Q54L_1 = .;
   IF (Q54L_2 <= -1) THEN Q54L_2 = .;
   IF (Q54M_1 <= -1) THEN Q54M_1 = .;
   IF (Q54M_2 <= -1) THEN Q54M_2 = .;
   IF (Q54N_1 <= -1) THEN Q54N_1 = .;
   IF (Q54N_2 <= -1) THEN Q54N_2 = .;
   IF (Q54O_1 <= -1) THEN Q54O_1 = .;
   IF (Q54O_2 <= -1) THEN Q54O_2 = .;
   IF (Q55 <= -1) THEN Q55 = .;
   IF (Q56 <= -1) THEN Q56 = .;
   IF (Q57 <= -1) THEN Q57 = .;
   IF (Q57A <= -1) THEN Q57A = .;
   IF (Q58 <= -1) THEN Q58 = .;
   IF (Q58_NO <= -1) THEN Q58_NO = .;
   IF (Q58A_PRI <= -1) THEN Q58A_PRI = .;
   IF (Q58A_SEC <= -1) THEN Q58A_SEC = .;
   IF (Q58A_FAC <= -1) THEN Q58A_FAC = .;
   IF (Q58A_RES <= -1) THEN Q58A_RES = .;
   IF (Q58B_PRI <= -1) THEN Q58B_PRI = .;
   IF (Q58B_SEC <= -1) THEN Q58B_SEC = .;
   IF (Q58B_FAC <= -1) THEN Q58B_FAC = .;
   IF (Q58B_RES <= -1) THEN Q58B_RES = .;
   IF (Q58C_PRI <= -1) THEN Q58C_PRI = .;
   IF (Q58C_SEC <= -1) THEN Q58C_SEC = .;
   IF (Q58C_FAC <= -1) THEN Q58C_FAC = .;
   IF (Q58C_RES <= -1) THEN Q58C_RES = .;
   IF (Q58D_PRI <= -1) THEN Q58D_PRI = .;
   IF (Q58D_SEC <= -1) THEN Q58D_SEC = .;
   IF (Q58D_FAC <= -1) THEN Q58D_FAC = .;
   IF (Q58D_RES <= -1) THEN Q58D_RES = .;
   IF (Q58E_PRI <= -1) THEN Q58E_PRI = .;
   IF (Q58E_SEC <= -1) THEN Q58E_SEC = .;
   IF (Q58E_FAC <= -1) THEN Q58E_FAC = .;
   IF (Q58E_RES <= -1) THEN Q58E_RES = .;
   IF (Q58F_PRI <= -1) THEN Q58F_PRI = .;
   IF (Q58F_SEC <= -1) THEN Q58F_SEC = .;
   IF (Q58F_FAC <= -1) THEN Q58F_FAC = .;
   IF (Q58F_RES <= -1) THEN Q58F_RES = .;
   IF (Q58G_PRI <= -1) THEN Q58G_PRI = .;
   IF (Q58G_SEC <= -1) THEN Q58G_SEC = .;
   IF (Q58G_FAC <= -1) THEN Q58G_FAC = .;
   IF (Q58G_RES <= -1) THEN Q58G_RES = .;
   IF (Q58H_PRI <= -1) THEN Q58H_PRI = .;
   IF (Q58H_SEC <= -1) THEN Q58H_SEC = .;
   IF (Q58H_FAC <= -1) THEN Q58H_FAC = .;
   IF (Q58H_RES <= -1) THEN Q58H_RES = .;
   IF (Q58I_PRI <= -1) THEN Q58I_PRI = .;
   IF (Q58I_SEC <= -1) THEN Q58I_SEC = .;
   IF (Q58I_FAC <= -1) THEN Q58I_FAC = .;
   IF (Q58I_RES <= -1) THEN Q58I_RES = .;
   IF (Q58J_PRI <= -1) THEN Q58J_PRI = .;
   IF (Q58J_SEC <= -1) THEN Q58J_SEC = .;
   IF (Q58J_FAC <= -1) THEN Q58J_FAC = .;
   IF (Q58J_RES <= -1) THEN Q58J_RES = .;
   IF (Q59_SER <= -1) THEN Q59_SER = .;
   IF (Q59_FAC <= -1) THEN Q59_FAC = .;
   IF (Q59_NO <= -1) THEN Q59_NO = .;
   IF (Q60_SER <= -1) THEN Q60_SER = .;
   IF (Q60_FAC <= -1) THEN Q60_FAC = .;
   IF (Q60_NO <= -1) THEN Q60_NO = .;
   IF (Q61_SER <= -1) THEN Q61_SER = .;
   IF (Q61_FAC <= -1) THEN Q61_FAC = .;
   IF (Q61_NO <= -1) THEN Q61_NO = .;
   IF (Q62_SER <= -1) THEN Q62_SER = .;
   IF (Q62_FAC <= -1) THEN Q62_FAC = .;
   IF (Q62_NO <= -1) THEN Q62_NO = .;
   IF (Q63_SER <= -1) THEN Q63_SER = .;
   IF (Q63_FAC <= -1) THEN Q63_FAC = .;
   IF (Q64_SER <= -1) THEN Q64_SER = .;
   IF (Q64_FAC <= -1) THEN Q64_FAC = .;
   IF (Q65_SER <= -1) THEN Q65_SER = .;
   IF (Q65_FAC <= -1) THEN Q65_FAC = .;
   IF (Q66_SER <= -1) THEN Q66_SER = .;
   IF (Q66_FAC <= -1) THEN Q66_FAC = .;
   IF (Q67_SER <= -1) THEN Q67_SER = .;
   IF (Q67_FAC <= -1) THEN Q67_FAC = .;
   IF (Q68_SER <= -1) THEN Q68_SER = .;
   IF (Q68_FAC <= -1) THEN Q68_FAC = .;
   IF (Q69_SER <= -1) THEN Q69_SER = .;
   IF (Q69_FAC <= -1) THEN Q69_FAC = .;
   IF (Q70 <= -1) THEN Q70 = .;
   IF (Q70A <= -1) THEN Q70A = .;
   IF (Q71 <= -1) THEN Q71 = .;
   IF (Q72 <= -1) THEN Q72 = .;
   IF (Q73 <= -1) THEN Q73 = .;
   IF (Q74 <= -1) THEN Q74 = .;
   IF (Q74A_MO <= -1) THEN Q74A_MO = .;
   IF (Q74A_YR <= -1) THEN Q74A_YR = .;
   IF (Q74A_TOT <= -1) THEN Q74A_TOT = .;
   IF (Q74A_GIV <= -1) THEN Q74A_GIV = .;
   IF (Q74A_NO <= -1) THEN Q74A_NO = .;
   IF (Q74A_PL <= -1) THEN Q74A_PL = .;
   IF (Q74B_MO <= -1) THEN Q74B_MO = .;
   IF (Q74B_YR <= -1) THEN Q74B_YR = .;
   IF (Q74B_TOT <= -1) THEN Q74B_TOT = .;
   IF (Q74B_GIV <= -1) THEN Q74B_GIV = .;
   IF (Q74B_NO <= -1) THEN Q74B_NO = .;
   IF (Q74B_PL <= -1) THEN Q74B_PL = .;
   IF (Q75 <= -1) THEN Q75 = .;
   IF (Q76 <= -1) THEN Q76 = .;
   IF (Q76A_MO <= -1) THEN Q76A_MO = .;
   IF (Q76A_YR <= -1) THEN Q76A_YR = .;
   IF (Q76B <= -1) THEN Q76B = .;
   IF (Q77_MO <= -1) THEN Q77_MO = .;
   IF (Q77_YR <= -1) THEN Q77_YR = .;
   IF (Q78_MO <= -1) THEN Q78_MO = .;
   IF (Q78_YR <= -1) THEN Q78_YR = .;
   IF (Q79 <= -1) THEN Q79 = .;
   IF (Q79A <= -1) THEN Q79A = .;
   IF (Q79A_MC1 <= -1) THEN Q79A_MC1 = .;
   IF (Q79A_MC2 <= -1) THEN Q79A_MC2 = .;
   IF (Q79A_MC3 <= -1) THEN Q79A_MC3 = .;
   IF (Q79A_MC4 <= -1) THEN Q79A_MC4 = .;
   IF (Q80 <= -1) THEN Q80 = .;
   IF (Q81 <= -1) THEN Q81 = .;
   IF (Q81A <= -1) THEN Q81A = .;
   IF (Q81B <= -1) THEN Q81B = .;
   IF (Q81C <= -1) THEN Q81C = .;
   IF (Q81D <= -1) THEN Q81D = .;
   IF (Q81E <= -1) THEN Q81E = .;
   IF (Q81F <= -1) THEN Q81F = .;
   IF (Q81G <= -1) THEN Q81G = .;
   IF (Q81H <= -1) THEN Q81H = .;
   IF (Q81I <= -1) THEN Q81I = .;
   IF (Q81J <= -1) THEN Q81J = .;
   IF (Q82 <= -1) THEN Q82 = .;
   IF (Q83 <= -1) THEN Q83 = .;
   IF (Q83A <= -1) THEN Q83A = .;
   IF (Q84 <= -1) THEN Q84 = .;
   IF (Q84_PER <= -1) THEN Q84_PER = .;
   IF (Q85 <= -1) THEN Q85 = .;
   IF (BATCHNO <= -1) THEN BATCHNO = .;
   IF (CORRFAC <= -1) THEN CORRFAC = .;
   IF (ALCHONLY <= -1) THEN ALCHONLY = .;
   IF (STRATUM <= -1) THEN STRATUM = .;
   IF (REGION <= -1) THEN REGION = .;
   IF (LOS <= -1) THEN LOS = .;
   IF (TRT_DUR <= -1) THEN TRT_DUR = .;
   IF (AGEA <= -1) THEN AGEA = .;
   IF (AGED <= -1) THEN AGED = .;
   IF (TXTYPE <= -1) THEN TXTYPE = .;
   IF (NUMDUALA <= -1) THEN NUMDUALA = .;
   IF (NUMDUALD <= -1) THEN NUMDUALD = .;
   IF (NUMDXA <= -1) THEN NUMDXA = .;
   IF (CWGHT <= -1.0000000) THEN CWGHT = .;
   IF (CWT1 <= -1.0000000) THEN CWT1 = .;
   IF (CWT2 <= -1.0000000) THEN CWT2 = .;
   IF (CWT3 <= -1.0000000) THEN CWT3 = .;
   IF (CWT4 <= -1.0000000) THEN CWT4 = .;
   IF (CWT5 <= -1.0000000) THEN CWT5 = .;
   IF (CWT6 <= -1.0000000) THEN CWT6 = .;
   IF (CWT7 <= -1.0000000) THEN CWT7 = .;
   IF (CWT8 <= -1.0000000) THEN CWT8 = .;
   IF (CWT9 <= -1.0000000) THEN CWT9 = .;
   IF (CWT10 <= -1.0000000) THEN CWT10 = .;
   IF (CWT11 <= -1.0000000) THEN CWT11 = .;
   IF (CWT12 <= -1.0000000) THEN CWT12 = .;
   IF (CWT13 <= -1.0000000) THEN CWT13 = .;
   IF (CWT14 <= -1.0000000) THEN CWT14 = .;
   IF (CWT15 <= -1.0000000) THEN CWT15 = .;
   IF (CWT16 <= -1.0000000) THEN CWT16 = .;
   IF (CWT17 <= -1.0000000) THEN CWT17 = .;
   IF (CWT18 <= -1.0000000) THEN CWT18 = .;
   IF (CWT19 <= -1.0000000) THEN CWT19 = .;
   IF (CWT20 <= -1.0000000) THEN CWT20 = .;
   IF (CWT21 <= -1.0000000) THEN CWT21 = .;
   IF (CWT22 <= -1.0000000) THEN CWT22 = .;
   IF (CWT23 <= -1.0000000) THEN CWT23 = .;
   IF (CWT24 <= -1.0000000) THEN CWT24 = .;
   IF (CWT25 <= -1.0000000) THEN CWT25 = .;
   IF (CWT26 <= -1.0000000) THEN CWT26 = .;
   IF (CWT27 <= -1.0000000) THEN CWT27 = .;
   IF (CWT28 <= -1.0000000) THEN CWT28 = .;
   IF (CWT29 <= -1.0000000) THEN CWT29 = .;
   IF (CWT30 <= -1.0000000) THEN CWT30 = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT CLIENTYP clientyp. COM_TIME com_time. ABS_STAT abs_stat.
         TRANS_NO trans_no. REABS reabs. QC_ABS qc_abs.
         Q2_MO q2_mo. Q2_YR q2_yr. Q3 q3ffffff.
         Q4 q4ffffff. Q5 q5ffffff. Q6 q6ffffff.
         Q7 q7ffffff. Q8_MO q8_mo. Q8_YR q8_yr.
         Q10 q10fffff. Q11 q11fffff. Q12 q12fffff.
         Q13 q13fffff. Q14 q14fffff. Q15 q15fffff.
         Q16 q16fffff. Q17 q17fffff. Q18 q18fffff.
         Q19 q19fffff. Q20 q20fffff. Q21 q21fffff.
         Q22 q22fffff. Q23 q23fffff. Q24 q24fffff.
         Q25 q25fffff. Q26 q26fffff. Q27 q27fffff.
         Q28 q28fffff. Q29 q29fffff. Q29A q29a.
         Q29A_MC1 q29a_mcf. Q29A_MC2 q29a_m0f. Q29A_MC3 q29a_m1f.
         Q29A_MC4 q29a_m2f. Q30 q30fffff. Q31 q31fffff.
         Q32 q32fffff. Q33 q33fffff. Q33A q33a.
         Q33A_MC1 q33a_mcf. Q33B_MC1 q33b_mcf. Q33B_MC2 q33b_m0f.
         Q33B_MC3 q33b_m1f. Q33B_MC4 q33b_m2f. Q33B_MC5 q33b_m3f.
         Q33B_MC6 q33b_m4f. Q33B q33b. Q33B1 q33b1fff.
         Q33B2 q33b2fff. Q35_EVER q35_ever. Q35_USED q35_used.
         Q35_AGE q35_age. Q36_EVER q36_ever. Q36_USED q36_used.
         Q36_AGE q36_age. Q37_EVER q37_ever. Q37_USED q37_used.
         Q37_AGE q37_age. Q38_EVER q38_ever. Q38_USED q38_used.
         Q38_AGE q38_age. Q39_EVER q39_ever. Q39_USED q39_used.
         Q39_AGE q39_age. Q40_EVER q40_ever. Q40_USED q40_used.
         Q40_AGE q40_age. Q41_EVER q41_ever. Q41_USED q41_used.
         Q41_AGE q41_age. Q42_EVER q42_ever. Q42_USED q42_used.
         Q42_AGE q42_age. Q43_EVER q43_ever. Q43_USED q43_used.
         Q43_AGE q43_age. Q44_EVER q44_ever. Q44_USED q44_used.
         Q44_AGE q44_age. Q45_EVER q45_ever. Q45_USED q45_used.
         Q45_AGE q45_age. Q46_EVER q46_ever. Q46_USED q46_used.
         Q46_AGE q46_age. Q47_EVER q47_ever. Q47_USED q47_used.
         Q47_AGE q47_age. Q48_EVER q48_ever. Q48_USED q48_used.
         Q48_AGE q48_age. Q49_EVER q49_ever. Q49_USED q49_used.
         Q49_AGE q49_age. Q50_EVER q50_ever. Q50_USED q50_used.
         Q50_AGE q50_age. Q51_EVER q51_ever. Q51_USED q51_used.
         Q51_AGE q51_age. Q52 q52fffff. Q53A q53a.
         Q53B q53b. Q53C q53c. Q54 q54fffff.
         Q54_TST1 q54_tstf. Q54_TST2 q54_ts0f. Q54_MO1 q54_mo1f.
         Q54_YR1 q54_yr1f. Q54_MO2 q54_mo2f. Q54_YR2 q54_yr2f.
         Q54A_1 q54a_1ff. Q54A_2 q54a_2ff. Q54B_1 q54b_1ff.
         Q54B_2 q54b_2ff. Q54C_1 q54c_1ff. Q54C_2 q54c_2ff.
         Q54D_1 q54d_1ff. Q54D_2 q54d_2ff. Q54E_1 q54e_1ff.
         Q54E_2 q54e_2ff. Q54F_1 q54f_1ff. Q54F_2 q54f_2ff.
         Q54G_1 q54g_1ff. Q54G_2 q54g_2ff. Q54H_1 q54h_1ff.
         Q54H_2 q54h_2ff. Q54I_1 q54i_1ff. Q54I_2 q54i_2ff.
         Q54J_1 q54j_1ff. Q54J_2 q54j_2ff. Q54K_1 q54k_1ff.
         Q54K_2 q54k_2ff. Q54L_1 q54l_1ff. Q54L_2 q54l_2ff.
         Q54M_1 q54m_1ff. Q54M_2 q54m_2ff. Q54N_1 q54n_1ff.
         Q54N_2 q54n_2ff. Q54O_1 q54o_1ff. Q54O_2 q54o_2ff.
         Q55 q55fffff. Q56 q56fffff. Q57 q57fffff.
         Q57A q57a. Q58 q58fffff. Q58_NO q58_no.
         Q58A_PRI q58a_pri. Q58A_SEC q58a_sec. Q58A_FAC q58a_fac.
         Q58A_RES q58a_res. Q58B_PRI q58b_pri. Q58B_SEC q58b_sec.
         Q58B_FAC q58b_fac. Q58B_RES q58b_res. Q58C_PRI q58c_pri.
         Q58C_SEC q58c_sec. Q58C_FAC q58c_fac. Q58C_RES q58c_res.
         Q58D_PRI q58d_pri. Q58D_SEC q58d_sec. Q58D_FAC q58d_fac.
         Q58D_RES q58d_res. Q58E_PRI q58e_pri. Q58E_SEC q58e_sec.
         Q58E_FAC q58e_fac. Q58E_RES q58e_res. Q58F_PRI q58f_pri.
         Q58F_SEC q58f_sec. Q58F_FAC q58f_fac. Q58F_RES q58f_res.
         Q58G_PRI q58g_pri. Q58G_SEC q58g_sec. Q58G_FAC q58g_fac.
         Q58G_RES q58g_res. Q58H_PRI q58h_pri. Q58H_SEC q58h_sec.
         Q58H_FAC q58h_fac. Q58H_RES q58h_res. Q58I_PRI q58i_pri.
         Q58I_SEC q58i_sec. Q58I_FAC q58i_fac. Q58I_RES q58i_res.
         Q58J_PRI q58j_pri. Q58J_SEC q58j_sec. Q58J_FAC q58j_fac.
         Q58J_RES q58j_res. Q59_SER q59_ser. Q59_FAC q59_fac.
         Q59_NO q59_no. Q60_SER q60_ser. Q60_FAC q60_fac.
         Q60_NO q60_no. Q61_SER q61_ser. Q61_FAC q61_fac.
         Q61_NO q61_no. Q62_SER q62_ser. Q62_FAC q62_fac.
         Q62_NO q62_no. Q63_SER q63_ser. Q63_FAC q63_fac.
         Q64_SER q64_ser. Q64_FAC q64_fac. Q65_SER q65_ser.
         Q65_FAC q65_fac. Q66_SER q66_ser. Q66_FAC q66_fac.
         Q67_SER q67_ser. Q67_FAC q67_fac. Q68_SER q68_ser.
         Q68_FAC q68_fac. Q69_SER q69_ser. Q69_FAC q69_fac.
         Q70 q70fffff. Q70A q70a. Q71 q71fffff.
         Q72 q72fffff. Q73 q73fffff. Q74 q74fffff.
         Q74A_MO q74a_mo. Q74A_YR q74a_yr. Q74A_TOT q74a_tot.
         Q74A_GIV q74a_giv. Q74A_NO q74a_no. Q74A_PL q74a_pl.
         Q74B_MO q74b_mo. Q74B_YR q74b_yr. Q74B_TOT q74b_tot.
         Q74B_GIV q74b_giv. Q74B_NO q74b_no. Q74B_PL q74b_pl.
         Q75 q75fffff. Q76 q76fffff. Q76A_MO q76a_mo.
         Q76A_YR q76a_yr. Q76B q76b. Q77_MO q77_mo.
         Q77_YR q77_yr. Q78_MO q78_mo. Q78_YR q78_yr.
         Q79 q79fffff. Q79A q79a. Q79A_MC1 q79a_mcf.
         Q79A_MC2 q79a_m0f. Q79A_MC3 q79a_m1f. Q79A_MC4 q79a_m2f.
         Q80 q80fffff. Q81 q81fffff. Q81A q81a.
         Q81B q81b. Q81C q81c. Q81D q81d.
         Q81E q81e. Q81F q81f. Q81G q81g.
         Q81H q81h. Q81I q81i. Q81J q81j.
         Q82 q82fffff. Q83 q83fffff. Q83A q83a.
         Q84 q84fffff. Q84_PER q84_per. Q85 q85fffff.
         CORRFAC corrfac. ALCHONLY alchonly. STRATUM stratum.
         REGION region. LOS los. TRT_DUR trt_dur.
         AGEA agea. AGED aged. TXTYPE txtype.
          ;

RUN ;
